==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/CategoryToolTipLayerDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { AnnotationLayerDescription } from "./AnnotationLayerDescription";
import { markType } from "./type";
/**
 * @hidden
 */
export let CategoryToolTipLayerDescription = /*@__PURE__*/ (() => {
    class CategoryToolTipLayerDescription extends AnnotationLayerDescription {
        constructor() {
            super();
            this.dg = null;
            this.de = false;
        }
        get_type() {
            return "CategoryToolTipLayer";
        }
        get targetAxisRef() {
            return this.dg;
        }
        set targetAxisRef(a) {
            this.dg = a;
            this.e("TargetAxisRef");
        }
        get useInterpolation() {
            return this.de;
        }
        set useInterpolation(a) {
            this.de = a;
            this.e("UseInterpolation");
        }
    }
    CategoryToolTipLayerDescription.$t = /*@__PURE__*/ markType(CategoryToolTipLayerDescription, 'CategoryToolTipLayerDescription', AnnotationLayerDescription.$);
    return CategoryToolTipLayerDescription;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/CategoryToolTipLayerDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { AnnotationLayerDescription } from "./AnnotationLayerDescription";
import { markType } from "./type";
/**
 * @hidden
 */
export let CategoryToolTipLayerDescription = /*@__PURE__*/ (() => {
    class CategoryToolTipLayerDescription extends AnnotationLayerDescription {
        get_type() {
            return "CategoryToolTipLayer";
        }
        constructor() {
            super();
            this.gf = null;
            this.gd = false;
        }
        get targetAxisRef() {
            return this.gf;
        }
        set targetAxisRef(a) {
            this.gf = a;
            this.g("TargetAxisRef");
        }
        get useInterpolation() {
            return this.gd;
        }
        set useInterpolation(a) {
            this.gd = a;
            this.g("UseInterpolation");
        }
    }
    CategoryToolTipLayerDescription.$t = /*@__PURE__*/ markType(CategoryToolTipLayerDescription, 'CategoryToolTipLayerDescription', AnnotationLayerDescription.$);
    return CategoryToolTipLayerDescription;
})();
